@@ -129,7 +129,11 @@ initialState topts = do
                           , expectedFailure   = False
                           , randomSeed        = gen
                           , numSuccessShrinks = 0
-                          , numTryShrinks     = 0 },
+                          , numTryShrinks     = 0
+#if MIN_VERSION_QuickCheck(2,5,0)
+                          , numTotTryShrinks  = 0
+#endif
+                          },
                   modifyMVar out_var $ \str -> return ("", str))
     return (seed, mk_state)
 
